// Aprenent allows to make computations on polytopes such as finding vertices, intersecting, Minkowski sums, ...
//     Copyright (C) 2013 : Delos Vincent
//
//     This program is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
//
//     This program is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
//
//     You should have received a copy of the GNU General Public License
//     along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/// \file TabbedPane1.java
/// \author Delos Vincent

import java.io.*;
import java.awt.*;
import java.net.URL;
import java.awt.image.*;
import java.awt.event.*;
import java.util.*;

import javax.imageio.*;
import javax.sound.sampled.*;
import javax.swing.*;



public class TabbedPane1 extends JPanel
{
    TabbedPane1(String[] sons, String[] imatges, int nbImatges, String kindOfImg) {
	super(new BorderLayout());
	_sorteigSet = false;
	_sons = sons;
	_imatges = imatges;
	_nbImatges = nbImatges;
	addComponentToPanel();
    }

    public void setSoundsImg(String[] sons, String[] imatges, int nbImatges, String kindOfImg) {
	_sons = sons;
	_imatges = imatges;
	_nbImatges = nbImatges;
    }

    protected void addComponentToPanel() {
	FlowLayout experimentLayout = new FlowLayout();
	JButton applyButton = new JButton("<html> Tirar au s&ograve;rt </html>");
	_imatgespanel = new JPanel();
	_imatgespanel.setLayout(experimentLayout);
	experimentLayout.setAlignment(FlowLayout.CENTER);
	JPanel controls = new JPanel();
	controls.setLayout(new FlowLayout());

	//Add buttons to the experiment layout
	_primeraImatge = new JButton();
	_segonaImatge  = new JButton();
	_terceraImatge = new JButton();
	drawNumbers();
	paintImatges();
	_imatgespanel.add(_primeraImatge);
	_imatgespanel.add(_segonaImatge);
	_imatgespanel.add(_terceraImatge);

        
	//Process the Apply component orientation button press
	_primeraImatge.addActionListener(new ActionListener(){
		public void actionPerformed(ActionEvent e){
		    if (_primer == _sorteig && _sorteigSet == true) {
			sounds.playSounds("./son/moltbe.wav");
			drawNumbers();
			paintImatges();
			_sorteigSet = false;
		    }
		    else
			sounds.playSounds(_sons[_primer]);
		}
	    });
	_segonaImatge.addActionListener(new ActionListener(){
		public void actionPerformed(ActionEvent e){
		    if (_segon == _sorteig && _sorteigSet == true) {
			sounds.playSounds("./son/moltbe.wav");
			drawNumbers();
			paintImatges();
			_sorteigSet = false;
		    }
		    else
			sounds.playSounds(_sons[_segon]);
		}
	    });
	_terceraImatge.addActionListener(new ActionListener(){
		public void actionPerformed(ActionEvent e){
		    if (_tercer == _sorteig && _sorteigSet == true) {
			sounds.playSounds("./son/moltbe.wav");
			drawNumbers();
			paintImatges();
			_sorteigSet = false;
		    }
		    else
			sounds.playSounds(_sons[_tercer]);
		}
	    });

	//Left to right component orientation is selected by default
	_imatgespanel.setComponentOrientation(ComponentOrientation.LEFT_TO_RIGHT);
        
	//Add controls to set up the component orientation in the experiment layout
	controls.add(applyButton);
        
	//Process the Apply component orientation button press
	applyButton.addActionListener(new ActionListener(){
		public void actionPerformed(ActionEvent e){
		    drawNumber();
		    sounds.playSounds(_sons[_sorteig]);
		}
	    });
	add(_imatgespanel, BorderLayout.CENTER);
	add(controls, BorderLayout.SOUTH);
    }

    /// Choose the indices of the 3 elements to be displayed next.
    public void drawNumbers() {
	java.util.Random rand = new java.util.Random();
	_primer = rand.nextInt(_nbImatges);
	_segon  = rand.nextInt(_nbImatges);
	while (_primer == _segon)
	    _segon  = rand.nextInt(_nbImatges);
	_tercer = rand.nextInt(_nbImatges);
	while (_primer==_tercer  || _segon==_tercer)
	    _tercer = rand.nextInt(_nbImatges);
    }

    ImageIcon makeIcon(String imgLocation) {
	ClassLoader classLoader = getClass().getClassLoader();
	URL imageURL = classLoader.getResource(imgLocation);
	ImageIcon imIcon=null;
	if (imageURL != null) {
	    imIcon = new ImageIcon(imageURL);
	}
	else {
	    System.err.println("TabbedPane1::makeIcon() Resource icon not found: " + imgLocation);
	}
	return imIcon;
    }

    /// Once we know the indices of the 3 elements, displayed them.
    public void paintImatges() {
	// Primer
	try {
	    _primeraImatge.setIcon(makeIcon(_imatges[_primer]));
	}
	catch (Exception e) {
	    System.err.println("_nbImatges=" + _nbImatges + "; " + "_primer=" + _primer);
	    if (_imatges == null)
		System.err.println("Null pointer _imatges");
	    else
		System.err.println("_imatges[_primer] == " + _imatges[_primer]);
	    e.printStackTrace();
	    System.exit(1);
	}
	// Segon
	try {
	    _segonaImatge.setIcon(makeIcon(_imatges[_segon]));
	}
	catch (Exception e) {
	    System.err.println("_nbImatges=" + _nbImatges + "; " + "_segon=" + _segon);
	    if (_imatges == null)
		System.err.println("Null pointer _imatges");
	    else
		System.err.println("_imatges[_segon] == " + _imatges[_segon]);
	    e.printStackTrace();
	    System.exit(1);
	}
	// Tercer
	try {
	    _terceraImatge.setIcon(makeIcon(_imatges[_tercer]));
	}
	catch (Exception e) {
	    System.err.println("_nbImatges=" + _nbImatges + "; " + "_tercer=" + _tercer);
	    if (_imatges == null)
		System.err.println("Null pointer _imatges");
	    else
		System.err.println("_imatges[_tercer] == " + _imatges[_tercer]);
	    e.printStackTrace();
	    System.exit(1);
	}
	_imatgespanel.validate();
	_imatgespanel.repaint();
    }

    /// Choose the index of one of the 3 elements.
    public void drawNumber() {
	// Draw the random number to find.
	java.util.Random rand = new java.util.Random();
	_sorteig = rand.nextInt(3);
	if (_sorteig == 0)
	    _sorteig = _primer;
	else if (_sorteig == 1)
	    _sorteig = _segon;
	else if (_sorteig == 2)
	    _sorteig = _tercer;
	_sorteigSet = true;
    }
    


    JPanel _imatgespanel;
    JButton _primeraImatge;
    JButton _segonaImatge;
    JButton _terceraImatge;
    int _primer;
    int _segon;
    int _tercer;
    int _sorteig;
    boolean _sorteigSet;

    String[] _sons;
    String[] _imatges;
    int _nbImatges;

}
