// Aprenent allows to make computations on polytopes such as finding vertices, intersecting, Minkowski sums, ...
//     Copyright (C) 2013 : Delos Vincent
//
//     This program is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
//
//     This program is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
//
//     You should have received a copy of the GNU General Public License
//     along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/// \file TabbedPane1.java
/// \author Delos Vincent

import java.io.*;
import java.awt.*;
import java.net.URL;
import java.awt.image.*;
import java.awt.event.*;
import java.util.*;

import javax.imageio.*;
import javax.sound.sampled.*;
import javax.swing.*;


public class TabbedPane3 extends JPanel
{
    TabbedPane3(String[] sons, String[] imatges, int nbImatges, String kindOfImg) {
	super(new BorderLayout(20,20));
	addComponentsToPanel();
    }

    protected void addComponentsToPanel() {
	// Set _sorteig & _number2find
	drawNumbers();
	createImatges();
    }

    public void createImatges() {
	_panel2 = new JPanel(new FlowLayout(FlowLayout.CENTER));

	JPanel panel1 = new JPanel();
	_buttonImatgeLeft  = new JButton();
	_buttonImatgePlus  = new JButton("+");
	_buttonImatgeRight = new JButton();
	_buttonImatgePlus.setFont(new Font(
					   _buttonImatgePlus.getFont().getFontName(),
					   _buttonImatgePlus.getFont().getStyle(),
					   3*_buttonImatgePlus.getFont().getSize()));
	//_buttonImatgeLeft.setHorizontalAlignment(SwingConstants.LEFT);
	//_buttonImatgePlus.setHorizontalAlignment(SwingConstants.CENTER);
	//_buttonImatgeRight.setHorizontalAlignment(SwingConstants.RIGHT);
	panel1.add(_buttonImatgeLeft);
	panel1.add(_buttonImatgePlus);
	panel1.add(_buttonImatgeRight);
	paintImatges();

	JPanel panel2 = new JPanel(new GridLayout(4,3));
	_numberOfAllNumberButtons = 10;
	_allNumberButtons = new JButtonInt[_numberOfAllNumberButtons];
	for (int i=1; i<=_numberOfAllNumberButtons; ++i) {
	    String number = ""+i;
	    _allNumberButtons[i-1] = new JButtonInt(this, number, i);
	    _allNumberButtons[i-1].setFont(new Font(
						  _allNumberButtons[i-1].getFont().getFontName(),
						  _allNumberButtons[i-1].getFont().getStyle(),
						  3*_allNumberButtons[i-1].getFont().getSize()));
	    _allNumberButtons[i-1].addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e){
		    JButtonInt jb = (JButtonInt) e.getSource();
		    if (jb.buttonNumber() == getNumber2find()) {
			sounds.playSounds("./son/moltbe.wav");
			drawNumbers();
			paintImatges();
		    }
		    else {
			String soundFile = "./son/" + jb.buttonNumber() + ".wav";
			sounds.playSounds(soundFile);
		    }
		}
	    });

	    panel2.add(_allNumberButtons[i-1]);
	}
	_panel2.add(panel2);

	add(panel1,  BorderLayout.LINE_START);
	add(_panel2, BorderLayout.CENTER);
    }

    public void paintImatges() {
	String imgFileLeft  = "./img/ma_esquerra_" + _number2findLeft  + ".png";
	String imgFileRight = "./img/ma_dreta_" + _number2findRight + ".png";
	ImageIcon icoLeft  = makeIcon(imgFileLeft);
	ImageIcon icoRight = makeIcon(imgFileRight);
	_buttonImatgeLeft.setIcon(icoLeft);
	_buttonImatgeRight.setIcon(icoRight);
    }

    /// Draw a number between 1 and 10.
    public void drawNumbers() {
	// Draw the random number to find.
	java.util.Random rand = new java.util.Random();
	int min = 5;
	int randnum = rand.nextInt(min)+1;
	// We want a fresh new number!
	while (randnum == _number2findLeft)
	    randnum = rand.nextInt(min)+1;
	_number2findLeft = randnum;
	randnum = rand.nextInt(min)+1;
	// We want a fresh new number!
	while (randnum == _number2findRight)
	    randnum = rand.nextInt(min)+1;
	_number2findRight = randnum;
	_number2find = _number2findLeft + _number2findRight;
    }

    ImageIcon makeIcon(String imgLocation) {
      ClassLoader classLoader = getClass().getClassLoader();
      URL imageURL = classLoader.getResource(imgLocation);
      ImageIcon imIcon=null;
      if (imageURL != null) {
	imIcon = new ImageIcon(imageURL);
      }
      else {
	System.err.println("TabbedPane2::makeIcon() Resource icon not found: " + imgLocation);
      }
      return imIcon;
    }
   
    int getNumber2find() {return _number2find;}

    int getNumber2findLeft() {return _number2findLeft;}
   
    int getNumber2findRight() {return _number2findRight;}
   

    int _number2find;
    int _number2findLeft;
    int _number2findRight;

    JPanel _panel2;
    JButton _buttonImatgeLeft;
    JButton _buttonImatgePlus;
    JButton _buttonImatgeRight;

    JButtonInt[] _allNumberButtons;
    int _numberOfAllNumberButtons;

}
