// Aprenent allows to make computations on polytopes such as finding vertices, intersecting, Minkowski sums, ...
//     Copyright (C) 2013 : Delos Vincent
//
//     This program is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
//
//     This program is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
//
//     You should have received a copy of the GNU General Public License
//     along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/// \file ImgSoundsLoader.java
/// \author Delos Vincent

import java.io.*;
import java.awt.*;
import java.net.URL;
import java.awt.image.*;
import java.awt.event.*;
import java.util.*;


public class ImgSoundsLoader
{
    ImgSoundsLoader() {}

    static public String getMainIcon() {return "./img/apre2.gif";}

    static public String getSmallIcon() {return "./img/apre.gif";}

    static public int getAnimalsSize() {return 48;}

    static public String[] getAnimalsImatges() {
	int nbImatges = getAnimalsSize();
	String[] imatges = new String[nbImatges];
	imatges[0] = "./img/aguila.png";
	imatges[1] = "./img/aranya.png";
	imatges[2] = "./img/dofi.png";
	imatges[3] = "./img/formiga.png";
	imatges[4] = "./img/gat.png";
	imatges[5] = "./img/lleo.png";
	imatges[6] = "./img/marieta.png";
	imatges[7] = "./img/os.png";
	imatges[8] = "./img/pingui.png";
	imatges[9] = "./img/tigre.png";
	imatges[10] = "./img/elefant.png";
	imatges[11] = "./img/foca.png";
	imatges[12] = "./img/papallona.png";
	imatges[13] = "./img/peix.png";
	imatges[14] = "./img/ase.png";
	imatges[15] = "./img/ocell.png";
	imatges[16] = "./img/cavall.png";
	imatges[17] = "./img/zebra.png";
	imatges[18] = "./img/cranc.png";
	imatges[19] = "./img/girafa.png";
	imatges[20] = "./img/guepard.png";
	imatges[21] = "./img/llop.png";
	imatges[22] = "./img/morsa.png";
	imatges[23] = "./img/vaca.png";
	imatges[24] = "./img/porc.png";
	imatges[25] = "./img/toro.png";
	imatges[26] = "./img/cabra.png";
	imatges[27] = "./img/ca.png";
	imatges[28] = "./img/saltamarti.png";
	imatges[29] = "./img/xacal.png";
	imatges[30] = "./img/hiena.png";
	imatges[31] = "./img/esquirol.png";
	imatges[32] = "./img/iguana.png";
	imatges[33] = "./img/serp.png";
	imatges[34] = "./img/rinoceront.png";
	imatges[35] = "./img/balena.png";
	imatges[36] = "./img/narval.png";
	imatges[37] = "./img/jaguar.png";
	imatges[38] = "./img/vespa.png";
	imatges[39] = "./img/xai.png";
	imatges[40] = "./img/libellula.png";
	imatges[41] = "./img/cocodril.png";
	imatges[42] = "./img/komodo.png";
	//imatges[43] = "./img/unicorn.png";
	imatges[43] = "./img/cargol.png";
	imatges[44] = "./img/escarabat.png";
	imatges[45] = "./img/granota.png";
	imatges[46] = "./img/panda.png";
	imatges[47] = "./img/papagai.png";

	return imatges;
    }

    static public String[] getAnimalsSounds() {
	int nbImatges = getAnimalsSize();
	String[] sons = new String[nbImatges];
	sons[0] = "./son/aguila.wav";
	sons[1] = "./son/aranya.wav";
	sons[2] = "./son/dofi.wav";
	sons[3] = "./son/formiga.wav";
	sons[4] = "./son/gat.wav";
	sons[5] = "./son/lleo.wav";
	sons[6] = "./son/marieta.wav";
	sons[7] = "./son/os.wav";
	sons[8] = "./son/pingui.wav";
	sons[9] = "./son/tigre.wav";
	sons[10] = "./son/elefant.wav";
	sons[11] = "./son/foca.wav";
	sons[12] = "./son/papallona.wav";
	sons[13] = "./son/peix.wav";
	sons[14] = "./son/ase.wav";
	sons[15] = "./son/ocell.wav";
	sons[16] = "./son/cavall.wav";
	sons[17] = "./son/zebra.wav";
	sons[18] = "./son/cranc.wav";
	sons[19] = "./son/girafa.wav";
	sons[20] = "./son/guepard.wav";
	sons[21] = "./son/llop.wav";
	sons[22] = "./son/morsa.wav";
	sons[23] = "./son/vaca.wav";
	sons[24] = "./son/porc.wav";
	sons[25] = "./son/toro.wav";
	sons[26] = "./son/cabra.wav";
	sons[27] = "./son/ca.wav";
	sons[28] = "./son/saltamarti.wav";
	sons[29] = "./son/xacal.wav";
	sons[30] = "./son/hiena.wav";
	sons[31] = "./son/esquirol.wav";
	sons[32] = "./son/iguana.wav";
	sons[33] = "./son/serp.wav";
	sons[34] = "./son/rinoceront.wav";
	sons[35] = "./son/balena.wav";
	sons[36] = "./son/narval.wav";
	sons[37] = "./son/jaguar.wav";
	sons[38] = "./son/vespa.wav";
	sons[39] = "./son/xai.wav";
	sons[40] = "./son/libellula.wav";
	sons[41] = "./son/cocodril.wav";
	sons[42] = "./son/komodo.wav";
	sons[43] = "./son/cargol.wav";
	//sons[43] = "./son/unicorn.wav";
	sons[44] = "./son/escarabat.wav";
	sons[45] = "./son/granota.wav";
	sons[46] = "./son/panda.wav";
	sons[47] = "./son/papagai.wav";

	return sons;
    }

    static public int getColorsSize() {return 9;}

    static public String[] getColorsImatges() {
	int nbImatges = getColorsSize();
	String[] imatges = new String[nbImatges];
	imatges[0] = "./img/blau.png";
	imatges[1] = "./img/roig.png";
	imatges[2] = "./img/verd.png";
	imatges[3] = "./img/groc.png";
	imatges[4] = "./img/violeta.png";
	imatges[5] = "./img/negre.png";
	imatges[6] = "./img/blanc.png";
	imatges[7] = "./img/gris.png";
	imatges[8] = "./img/taronja.png";
	return imatges;
    }

    static public String[] getColorsSounds() {
	int nbImatges = getColorsSize();
	String[] sons = new String[nbImatges];
	sons[0] = "./son/blau.wav";
	sons[1] = "./son/roig.wav";
	sons[2] = "./son/verd.wav";
	sons[3] = "./son/groc.wav";
	sons[4] = "./son/violeta.wav";
	sons[5] = "./son/negre.wav";
	sons[6] = "./son/blanc.wav";
	sons[7] = "./son/gris.wav";
	sons[8] = "./son/taronja.wav";
	return sons;
    }

    static public int getFormesSize() {return 5;}

    static public String[] getFormesImatges() {
	int nbImatges = getFormesSize();
	String[] imatges = new String[nbImatges];
	imatges[0] = "./img/triangle.png";
	imatges[1] = "./img/quadrat.png";
	imatges[2] = "./img/rectangle.png";
	imatges[3] = "./img/estel.png";
	imatges[4] = "./img/cercle.png";
	return imatges;
    }

   static public String[] getFormesSounds() {
	int nbImatges = getFormesSize();
	String[] sons = new String[nbImatges];
	sons[0] = "./son/triangle.wav";
	sons[1] = "./son/quadrat.wav";
	sons[2] = "./son/rectangle.wav";
	sons[3] = "./son/estel.wav";
	sons[4] = "./son/cercle.wav";
	return sons;
    }

    static public int getNensSize() {return 13;}

    static public String[] getNensImatges() {
	int nbNens = getNensSize();
	String[] imatges = new String[nbNens];
	imatges[0] = "./img/nens_arena.png";
	imatges[1] = "./img/nens_beguda.png";
	imatges[2] = "./img/nens_bici.png";
	imatges[3] = "./img/nens_cotxe.png";
	imatges[4] = "./img/nens_dolent.png";
	imatges[5] = "./img/nens_gelat.png";
	imatges[6] = "./img/nens_globus.png";
	imatges[7] = "./img/nens_gronxador.png";
	imatges[8] = "./img/nens_papallona.png";
	imatges[9] = "./img/nens_petons.png";
	imatges[10] = "./img/nens_pilota_dent.png";
	imatges[11] = "./img/nens_present_enamorat.png";
	imatges[12] = "./img/nens_tobogan.png";
	return imatges;
    }

   static public String[] getNensSounds() {
	int nbNens = getNensSize();
	String[] sons = new String[nbNens];
	sons[0] = "./son/nens_arena.wav";
	sons[1] = "./son/nens_beguda.wav";
	sons[2] = "./son/nens_bici.wav";
	sons[3] = "./son/nens_cotxe.wav";
	sons[4] = "./son/nens_dolent.wav";
	sons[5] = "./son/nens_gelat.wav";
	sons[6] = "./son/nens_globus.wav";
	sons[7] = "./son/nens_gronxador.wav";
	sons[8] = "./son/nens_papallona.wav";
	sons[9] = "./son/nens_petons.wav";
	sons[10] = "./son/nens_pilota_dent.wav";
	sons[11] = "./son/nens_present_enamorat.wav";
	sons[12] = "./son/nens_tobogan.wav";
	return sons;
    }

} 
